@@ -1,4 +1,4 @@
 from .kernel import SSHKernel
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     SSHKernel.run_as_main()
